[nautilus] nautilus-file: fix regression with small thumbnails images



commit e928d302a0381c9527a1e56105552598dee070b8
Author: Cosimo Cecchi <cosimoc gnome org>
Date:   Wed Jan 28 16:06:45 2015 +0000

    nautilus-file: fix regression with small thumbnails images
    
    Commit 1968379a2e2dc7e601a0379856c05da5ed04d01d changed the code here to
    use the new names for icon sizes, but not consistently.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=743651

 libnautilus-private/nautilus-file.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/libnautilus-private/nautilus-file.c b/libnautilus-private/nautilus-file.c
index b4a3ebd..b4a9fca 100644
--- a/libnautilus-private/nautilus-file.c
+++ b/libnautilus-private/nautilus-file.c
@@ -4459,9 +4459,9 @@ nautilus_file_get_thumbnail_icon (NautilusFile *file,
                        thumb_scale = (double) modified_size / s;
                }
 
-               /* Make sure that icons don't get smaller than NAUTILUS_ICON_SIZE_SMALLEST */
-               if (s * thumb_scale <= NAUTILUS_CANVAS_ICON_SIZE_SMALL) {
-                       thumb_scale = (double) NAUTILUS_CANVAS_ICON_SIZE_SMALL / s;
+               /* Make sure that icons don't get smaller than NAUTILUS_LIST_ICON_SIZE_SMALL */
+               if (s * thumb_scale <= NAUTILUS_LIST_ICON_SIZE_SMALL) {
+                       thumb_scale = (double) NAUTILUS_LIST_ICON_SIZE_SMALL / s;
                }
 
                if (file->details->thumbnail_scale == thumb_scale &&


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]